.. image:: https://raw.githubusercontent.com/pymeasure/pymeasure/master/docs/images/PyMeasure.png
    :alt: PyMeasure Scientific package

PyMeasure scientific package
############################

PyMeasure makes scientific measurements easy to set up and run.
The package contains a repository of instrument classes and a system for running experiment procedures, which provides graphical interfaces for graphing live data and managing queues of experiments.
Both parts of the package are independent, and when combined provide all the necessary requirements for advanced measurements with only limited coding.

PyMeasure is currently under active development, so please report any issues you experience to our `Issues page`_.

.. _Issues page: https://github.com/pymeasure/pymeasure/issues

PyMeasure runs on Python 3.8-3.12, and is tested with continuous-integration on Linux, macOS, and Windows.

.. image:: https://github.com/pymeasure/pymeasure/actions/workflows/pymeasure_CI.yml/badge.svg
    :target: https://github.com/pymeasure/pymeasure/actions/workflows/pymeasure_CI.yml

.. image:: http://readthedocs.org/projects/pymeasure/badge/?version=latest
    :target: http://pymeasure.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.595633.svg
   :target: https://doi.org/10.5281/zenodo.595633

.. image:: https://anaconda.org/conda-forge/pymeasure/badges/version.svg
   :target: https://anaconda.org/conda-forge/pymeasure

.. image:: https://anaconda.org/conda-forge/pymeasure/badges/downloads.svg
   :target: https://anaconda.org/conda-forge/pymeasure

.. image:: https://codecov.io/gh/pymeasure/pymeasure/graph/badge.svg
   :target: https://codecov.io/gh/pymeasure/pymeasure


Quick start
===========

Check out `the documentation`_ for the `quick start guide`_, that covers the installation of Python and PyMeasure.

There are a number of examples in the `examples`_ directory that can help you get up and running.

.. _the documentation: http://pymeasure.readthedocs.org/en/latest/
.. _quick start guide: http://pymeasure.readthedocs.io/en/latest/quick_start.html
.. _examples: https://github.com/pymeasure/pymeasure/tree/master/examples
